# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`osg`](#osg): Class for common OSG parameters and common resources
* [`osg::cacerts::updater`](#osgcacertsupdater): Manage OSG CA certs updater
* [`osg::ce`](#osgce): Manage OSG CE
* [`osg::client`](#osgclient): Manage OSG client
* [`osg::cvmfs`](#osgcvmfs): Manage OSG CVMFS
* [`osg::fetchcrl`](#osgfetchcrl): Manage OSG fetchcrl
* [`osg::gridftp`](#osggridftp): Manage OSG GridFTP.
* [`osg::lcmaps_voms`](#osglcmaps_voms): Manage lcmaps VOMs
* [`osg::squid`](#osgsquid): Manage OSG squid
* [`osg::utils`](#osgutils): Manage OSG utils
* [`osg::wn`](#osgwn): Manage OSG worker node resources

#### Private Classes

* `osg::cacerts`: Manage OSG CA certs
* `osg::ce::config`: Manage OSG CE configs
* `osg::ce::install`: Install OSG CE
* `osg::ce::service`: Manage OSG CE Services
* `osg::ce::users`: Manage OSG CE Users
* `osg::client::config`: Manage OSG client configs
* `osg::client::install`: Install OSG client
* `osg::client::service`: Manage OSG client services
* `osg::configure`: Manage osg-configure
* `osg::configure::misc`: Manage osg-configure-misc
* `osg::configure::site_info`: Manage OSG configuration site info
* `osg::cvmfs::config`: Manage OSG CVMFS configs
* `osg::cvmfs::install`: Install CVMFS
* `osg::cvmfs::service`: Manage CVMFS service
* `osg::cvmfs::user`: Manage CVMFS users
* `osg::gridftp::config`: Manage GridFTP configs
* `osg::gridftp::install`: Install GridFTP
* `osg::gridftp::service`: Manage GridFTP service
* `osg::lcmaps_voms::config`: Manage lcmaps voms configs
* `osg::lcmaps_voms::install`: Install lcmaps voms support
* `osg::repos`: Manage OSG repos

### Defined types

* [`osg::lcmaps_voms::user`](#osglcmaps_vomsuser): Manage lcmaps VOMs user
* [`osg::lcmaps_voms::vo`](#osglcmaps_vomsvo): Manage lcmaps VOMs VO entry

### Resource types

* [`osg_gip_config`](#osg_gip_config): This type writes values to `/etc/osg/config.d/30-gip.ini`
* [`osg_local_site_settings`](#osg_local_site_settings): This type writes values to `/etc/osg/config.d/99-local-site-settings.ini`.

## Classes

### <a name="osg"></a>`osg`

Class for common OSG parameters and common resources

#### Parameters

The following parameters are available in the `osg` class:

* [`osg_release`](#osg_release)
* [`repo_baseurl_bit`](#repo_baseurl_bit)
* [`repo_development_baseurl_bit`](#repo_development_baseurl_bit)
* [`repo_testing_baseurl_bit`](#repo_testing_baseurl_bit)
* [`repo_upcoming_baseurl_bit`](#repo_upcoming_baseurl_bit)
* [`repo_use_mirrors`](#repo_use_mirrors)
* [`repo_gpgkey`](#repo_gpgkey)
* [`enable_osg`](#enable_osg)
* [`enable_osg_empty`](#enable_osg_empty)
* [`enable_osg_contrib`](#enable_osg_contrib)
* [`manage_epel`](#manage_epel)
* [`auth_type`](#auth_type)
* [`cacerts_package_name`](#cacerts_package_name)
* [`cacerts_package_ensure`](#cacerts_package_ensure)
* [`shared_certs_path`](#shared_certs_path)
* [`globus_tcp_port_range_min`](#globus_tcp_port_range_min)
* [`globus_tcp_port_range_max`](#globus_tcp_port_range_max)
* [`globus_tcp_source_range_min`](#globus_tcp_source_range_min)
* [`globus_tcp_source_range_max`](#globus_tcp_source_range_max)
* [`enable_exported_resources`](#enable_exported_resources)
* [`exported_resources_export_tag`](#exported_resources_export_tag)
* [`exported_resource_collect_tag`](#exported_resource_collect_tag)
* [`site_info_group`](#site_info_group)
* [`site_info_host_name`](#site_info_host_name)
* [`site_info_resource`](#site_info_resource)
* [`site_info_resource_group`](#site_info_resource_group)
* [`site_info_sponsor`](#site_info_sponsor)
* [`site_info_site_policy`](#site_info_site_policy)
* [`site_info_contact`](#site_info_contact)
* [`site_info_email`](#site_info_email)
* [`site_info_city`](#site_info_city)
* [`site_info_country`](#site_info_country)
* [`site_info_longitude`](#site_info_longitude)
* [`site_info_latitude`](#site_info_latitude)
* [`squid_location`](#squid_location)
* [`purge_local_site_settings`](#purge_local_site_settings)
* [`purge_gip_config`](#purge_gip_config)

##### <a name="osg_release"></a>`osg_release`

Data type: `Enum['3.5']`

OSG release

Default value: `'3.5'`

##### <a name="repo_baseurl_bit"></a>`repo_baseurl_bit`

Data type: `Optional[String]`

Base URL for osg repo, eg: `https://repo.opensciencegrid.org`

Default value: `'https://repo.opensciencegrid.org'`

##### <a name="repo_development_baseurl_bit"></a>`repo_development_baseurl_bit`

Data type: `Optional[String]`

Base URL for osg-development repo, default: `https://repo.opensciencegrid.org`

Default value: ``undef``

##### <a name="repo_testing_baseurl_bit"></a>`repo_testing_baseurl_bit`

Data type: `Optional[String]`

Base URL for osg-testubg repo, default: `https://repo.opensciencegrid.org`

Default value: ``undef``

##### <a name="repo_upcoming_baseurl_bit"></a>`repo_upcoming_baseurl_bit`

Data type: `Optional[String]`

Base URL for osg-upcoming repo, default: `https://repo.opensciencegrid.org`

Default value: ``undef``

##### <a name="repo_use_mirrors"></a>`repo_use_mirrors`

Data type: `Boolean`

Sets if repos should use mirrors

Default value: ``true``

##### <a name="repo_gpgkey"></a>`repo_gpgkey`

Data type: `Optional[String]`

Path to repo GPG key

Default value: ``undef``

##### <a name="enable_osg"></a>`enable_osg`

Data type: `Boolean`

Enable the osg repo

Default value: ``true``

##### <a name="enable_osg_empty"></a>`enable_osg_empty`

Data type: `Boolean`

Enable the osg-empty repo

Default value: ``true``

##### <a name="enable_osg_contrib"></a>`enable_osg_contrib`

Data type: `Boolean`

Enable the osg-contrib repo

Default value: ``false``

##### <a name="manage_epel"></a>`manage_epel`

Data type: `Boolean`

Manage the EPEL repo

Default value: ``true``

##### <a name="auth_type"></a>`auth_type`

Data type: `Enum['lcmaps_voms']`

Grid authentication type

Default value: `'lcmaps_voms'`

##### <a name="cacerts_package_name"></a>`cacerts_package_name`

Data type: `Enum['osg-ca-certs', 'igtf-ca-certs', 'empty-ca-certs']`

Package name for osg-ca-certs

Default value: `'osg-ca-certs'`

##### <a name="cacerts_package_ensure"></a>`cacerts_package_ensure`

Data type: `String`

CA certs package ensure

Default value: `'installed'`

##### <a name="shared_certs_path"></a>`shared_certs_path`

Data type: `String`

Path to location of shared certs, for example if storing certs on NFS

Default value: `'/opt/grid-certificates'`

##### <a name="globus_tcp_port_range_min"></a>`globus_tcp_port_range_min`

Data type: `Integer[0, 65535]`

Min for GLOBUS_TCP_PORT_RANGE

Default value: `40000`

##### <a name="globus_tcp_port_range_max"></a>`globus_tcp_port_range_max`

Data type: `Integer[0, 65535]`

Max for GLOBUS_TCP_PORT_RANGE

Default value: `41999`

##### <a name="globus_tcp_source_range_min"></a>`globus_tcp_source_range_min`

Data type: `Integer[0, 65535]`

Min for GLOBUS_TCP_SOURCE_RANGE

Default value: `40000`

##### <a name="globus_tcp_source_range_max"></a>`globus_tcp_source_range_max`

Data type: `Integer[0, 65535]`

Max for GLOBUS_TCP_SOURCE_RANGE

Default value: `41999`

##### <a name="enable_exported_resources"></a>`enable_exported_resources`

Data type: `Boolean`

Enable exported resources, useful when services like Squid and CE live on different hosts

Default value: ``false``

##### <a name="exported_resources_export_tag"></a>`exported_resources_export_tag`

Data type: `String`

Exported resources export tag

Default value: `$facts['domain']`

##### <a name="exported_resource_collect_tag"></a>`exported_resource_collect_tag`

Data type: `String`

Exported resources collect tag

Default value: `$facts['domain']`

##### <a name="site_info_group"></a>`site_info_group`

Data type: `String`

osg-configure Site Information/group

Default value: `'OSG'`

##### <a name="site_info_host_name"></a>`site_info_host_name`

Data type: `String`

osg-configure Site Information/host_name

Default value: `$::fqdn`

##### <a name="site_info_resource"></a>`site_info_resource`

Data type: `String`

osg-configure Site Information/resource

Default value: `'UNAVAILABLE'`

##### <a name="site_info_resource_group"></a>`site_info_resource_group`

Data type: `String`

osg-configure Site Information/resource_group

Default value: `'UNAVAILABLE'`

##### <a name="site_info_sponsor"></a>`site_info_sponsor`

Data type: `String`

osg-configure Site Information/sponsor

Default value: `'UNAVAILABLE'`

##### <a name="site_info_site_policy"></a>`site_info_site_policy`

Data type: `String`

osg-configure Site Information/site_policy

Default value: `'UNAVAILABLE'`

##### <a name="site_info_contact"></a>`site_info_contact`

Data type: `String`

osg-configure Site Information/contact

Default value: `'UNAVAILABLE'`

##### <a name="site_info_email"></a>`site_info_email`

Data type: `String`

osg-configure Site Information/email

Default value: `'UNAVAILABLE'`

##### <a name="site_info_city"></a>`site_info_city`

Data type: `String`

osg-configure Site Information/city

Default value: `'UNAVAILABLE'`

##### <a name="site_info_country"></a>`site_info_country`

Data type: `String`

osg-configure Site Information/country

Default value: `'UNAVAILABLE'`

##### <a name="site_info_longitude"></a>`site_info_longitude`

Data type: `String`

osg-configure Site Information/longitude

Default value: `'UNAVAILABLE'`

##### <a name="site_info_latitude"></a>`site_info_latitude`

Data type: `String`

osg-configure Site Information/latitude

Default value: `'UNAVAILABLE'`

##### <a name="squid_location"></a>`squid_location`

Data type: `Optional[String]`

osg-confgiure Squid/location

Default value: ``undef``

##### <a name="purge_local_site_settings"></a>`purge_local_site_settings`

Data type: `Boolean`

Purge unmanaged osg_local_site_settings resources

Default value: ``true``

##### <a name="purge_gip_config"></a>`purge_gip_config`

Data type: `Boolean`

Purge unmanaged osg_gip_config

Default value: ``true``

### <a name="osgcacertsupdater"></a>`osg::cacerts::updater`

Manage OSG CA certs updater

#### Parameters

The following parameters are available in the `osg::cacerts::updater` class:

* [`ensure`](#ensure)
* [`min_age`](#min_age)
* [`max_age`](#max_age)
* [`random_wait`](#random_wait)
* [`quiet`](#quiet)
* [`logfile`](#logfile)
* [`package_name`](#package_name)
* [`package_ensure`](#package_ensure)
* [`service_name`](#service_name)
* [`service_ensure`](#service_ensure)
* [`service_enable`](#service_enable)
* [`config_replace`](#config_replace)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent', 'disabled']`

State of the resources managed by this class
`disabled` will install the necessary packages but disable the service

Default value: `'present'`

##### <a name="min_age"></a>`min_age`

Data type: `Integer`

Min time between running updater

Default value: `23`

##### <a name="max_age"></a>`max_age`

Data type: `Integer`

Max time between running updater

Default value: `72`

##### <a name="random_wait"></a>`random_wait`

Data type: `Integer`

Random wait time

Default value: `30`

##### <a name="quiet"></a>`quiet`

Data type: `Boolean`

Only display errors

Default value: ``true``

##### <a name="logfile"></a>`logfile`

Data type: `Variant[Boolean,Undef,String]`

Path to logfile

Default value: ``false``

##### <a name="package_name"></a>`package_name`

Data type: `String`

Package name

Default value: `'osg-ca-certs-updater'`

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

Package ensure value

Default value: `'UNSET'`

##### <a name="service_name"></a>`service_name`

Data type: `String`

Service name

Default value: `'osg-ca-certs-updater-cron'`

##### <a name="service_ensure"></a>`service_ensure`

Data type: `String`

Service ensure value

Default value: `'UNSET'`

##### <a name="service_enable"></a>`service_enable`

Data type: `String`

Service enable value

Default value: `'UNSET'`

##### <a name="config_replace"></a>`config_replace`

Data type: `Boolean`

Should the cron config be replaced

Default value: ``true``

### <a name="osgce"></a>`osg::ce`

Manage OSG CE

#### Parameters

The following parameters are available in the `osg::ce` class:

* [`storage_grid_dir`](#storage_grid_dir)
* [`storage_app_dir`](#storage_app_dir)
* [`storage_data_dir`](#storage_data_dir)
* [`storage_worker_node_temp`](#storage_worker_node_temp)
* [`storage_site_read`](#storage_site_read)
* [`storage_site_write`](#storage_site_write)
* [`batch_system`](#batch_system)
* [`batch_system_prefix`](#batch_system_prefix)
* [`pbs_server`](#pbs_server)
* [`manage_hostcert`](#manage_hostcert)
* [`hostcert_source`](#hostcert_source)
* [`hostkey_source`](#hostkey_source)
* [`htcondor_ce_port`](#htcondor_ce_port)
* [`htcondor_ce_shared_port`](#htcondor_ce_shared_port)
* [`manage_firewall`](#manage_firewall)
* [`osg_local_site_settings`](#osg_local_site_settings)
* [`osg_gip_configs`](#osg_gip_configs)
* [`manage_users`](#manage_users)
* [`condor_uid`](#condor_uid)
* [`condor_gid`](#condor_gid)
* [`gratia_uid`](#gratia_uid)
* [`gratia_gid`](#gratia_gid)
* [`condor_ce_config_content`](#condor_ce_config_content)
* [`condor_ce_config_source`](#condor_ce_config_source)
* [`blahp_local_submit_content`](#blahp_local_submit_content)
* [`blahp_local_submit_source`](#blahp_local_submit_source)
* [`include_view`](#include_view)
* [`view_port`](#view_port)
* [`per_job_history_dir`](#per_job_history_dir)
* [`gratia_probes_cron_service_ensure`](#gratia_probes_cron_service_ensure)
* [`gratia_probes_cron_service_enable`](#gratia_probes_cron_service_enable)

##### <a name="storage_grid_dir"></a>`storage_grid_dir`

Data type: `String`

osg-configure Storage/grid_dir

Default value: `'/etc/osg/wn-client/'`

##### <a name="storage_app_dir"></a>`storage_app_dir`

Data type: `String`

osg-configure Storage/app_dir

Default value: `'UNAVAILABLE'`

##### <a name="storage_data_dir"></a>`storage_data_dir`

Data type: `String`

osg-configure Storage/data_dir

Default value: `'UNAVAILABLE'`

##### <a name="storage_worker_node_temp"></a>`storage_worker_node_temp`

Data type: `String`

osg-configure Storage/worker_node_temp

Default value: `'UNAVAILABLE'`

##### <a name="storage_site_read"></a>`storage_site_read`

Data type: `String`

osg-configure Storage/site_read

Default value: `'UNAVAILABLE'`

##### <a name="storage_site_write"></a>`storage_site_write`

Data type: `String`

osg-configure Storage/site_write

Default value: `'UNAVAILABLE'`

##### <a name="batch_system"></a>`batch_system`

Data type: `Enum['torque', 'pbs', 'slurm']`

Batch system used to submit jobs

Default value: `'torque'`

##### <a name="batch_system_prefix"></a>`batch_system_prefix`

Data type: `String`

Prefix of where batch system commands are installed

Default value: `'/usr'`

##### <a name="pbs_server"></a>`pbs_server`

Data type: `String`

PBS server address when `batch_system` is `torque` or `pbs`

Default value: `'UNAVAILABLE'`

##### <a name="manage_hostcert"></a>`manage_hostcert`

Data type: `Boolean`

Boolean that determines if hostcert is managed

Default value: ``true``

##### <a name="hostcert_source"></a>`hostcert_source`

Data type: `Optional[String]`

The source of the hostcert

Default value: ``undef``

##### <a name="hostkey_source"></a>`hostkey_source`

Data type: `Optional[String]`

The source of the hostkey

Default value: ``undef``

##### <a name="htcondor_ce_port"></a>`htcondor_ce_port`

Data type: `Integer[0, 65535]`

HTCondor CE port

Default value: `9619`

##### <a name="htcondor_ce_shared_port"></a>`htcondor_ce_shared_port`

Data type: `Integer[0, 65535]`

HTCondor CE shared port

Default value: `9620`

##### <a name="manage_firewall"></a>`manage_firewall`

Data type: `Boolean`

Boolean taht determines if firewall rules should be managed

Default value: ``true``

##### <a name="osg_local_site_settings"></a>`osg_local_site_settings`

Data type: `Hash`

Extra configs for osg-configure local site settings
Example: `{ 'Local Settings/PATH' => { 'value' => '/opt/singularity/bin:$PATH' } }`

Default value: `{}`

##### <a name="osg_gip_configs"></a>`osg_gip_configs`

Data type: `Hash`

Extra configs for osg-configure GIP configs
Example: `{ 'Subcluster owens/ram_mb' => { 'value' => 128000 } }`

Default value: `{}`

##### <a name="manage_users"></a>`manage_users`

Data type: `Boolean`

Boolean of whether to manage users and groups

Default value: ``true``

##### <a name="condor_uid"></a>`condor_uid`

Data type: `Optional[Integer]`

The UID of condor user

Default value: ``undef``

##### <a name="condor_gid"></a>`condor_gid`

Data type: `Optional[Integer]`

The GID of condor group

Default value: ``undef``

##### <a name="gratia_uid"></a>`gratia_uid`

Data type: `Optional[Integer]`

The UID of gratia user

Default value: ``undef``

##### <a name="gratia_gid"></a>`gratia_gid`

Data type: `Optional[Integer]`

The GID of gratia group

Default value: ``undef``

##### <a name="condor_ce_config_content"></a>`condor_ce_config_content`

Data type: `Optional[String]`

Content for /etc/condor-ce/config.d/99-local.conf

Default value: ``undef``

##### <a name="condor_ce_config_source"></a>`condor_ce_config_source`

Data type: `Optional[String]`

Source for /etc/condor-ce/config.d/99-local.conf

Default value: ``undef``

##### <a name="blahp_local_submit_content"></a>`blahp_local_submit_content`

Data type: `Optional[String]`

Content for blahp local submit attributes

Default value: ``undef``

##### <a name="blahp_local_submit_source"></a>`blahp_local_submit_source`

Data type: `Optional[String]`

Source for blahp local submit attributes

Default value: ``undef``

##### <a name="include_view"></a>`include_view`

Data type: `Boolean`

Boolean to determine if adding Condor CE View

Default value: ``false``

##### <a name="view_port"></a>`view_port`

Data type: `Integer[0, 65535]`

Port for Condor CE View

Default value: `8080`

##### <a name="per_job_history_dir"></a>`per_job_history_dir`

Data type: `Stdlib::Absolutepath`

Path used for Gratia probe DataFolder

Default value: `'/var/lib/gratia/data'`

##### <a name="gratia_probes_cron_service_ensure"></a>`gratia_probes_cron_service_ensure`

Data type: `String`

Service ensure for gratia-probes-cron service

Default value: `'running'`

##### <a name="gratia_probes_cron_service_enable"></a>`gratia_probes_cron_service_enable`

Data type: `Boolean`

Service enable for gratia-probes-cron service

Default value: ``true``

### <a name="osgclient"></a>`osg::client`

Manage OSG client

#### Parameters

The following parameters are available in the `osg::client` class:

* [`with_condor`](#with_condor)
* [`with_condor_ce`](#with_condor_ce)
* [`condor_lowport`](#condor_lowport)
* [`condor_highport`](#condor_highport)
* [`condor_schedd_host`](#condor_schedd_host)
* [`condor_collector_host`](#condor_collector_host)
* [`manage_firewall`](#manage_firewall)
* [`enable_condor_service`](#enable_condor_service)
* [`enable_condor_ce_service`](#enable_condor_ce_service)
* [`condor_configs_override`](#condor_configs_override)
* [`condor_ce_configs_override`](#condor_ce_configs_override)

##### <a name="with_condor"></a>`with_condor`

Data type: `Boolean`

Include Condor support

Default value: ``true``

##### <a name="with_condor_ce"></a>`with_condor_ce`

Data type: `Boolean`

Include Condor CE support

Default value: ``true``

##### <a name="condor_lowport"></a>`condor_lowport`

Data type: `Integer[0, 65535]`

Condor lowport

Default value: `40000`

##### <a name="condor_highport"></a>`condor_highport`

Data type: `Integer[0, 65535]`

Condor highport

Default value: `41999`

##### <a name="condor_schedd_host"></a>`condor_schedd_host`

Data type: `Optional[String]`

Condor schedd host

Default value: ``undef``

##### <a name="condor_collector_host"></a>`condor_collector_host`

Data type: `Optional[String]`

Condor collector host

Default value: ``undef``

##### <a name="manage_firewall"></a>`manage_firewall`

Data type: `Boolean`

Manage the firewall rules

Default value: ``true``

##### <a name="enable_condor_service"></a>`enable_condor_service`

Data type: `Boolean`

Enable Condor service

Default value: ``false``

##### <a name="enable_condor_ce_service"></a>`enable_condor_ce_service`

Data type: `Boolean`

Enable Condor CE service

Default value: ``false``

##### <a name="condor_configs_override"></a>`condor_configs_override`

Data type: `Hash`

Config overrides for Condor

Default value: `{}`

##### <a name="condor_ce_configs_override"></a>`condor_ce_configs_override`

Data type: `Hash`

Config overrides for Condor CE

Default value: `{}`

### <a name="osgcvmfs"></a>`osg::cvmfs`

Manage OSG CVMFS

#### Parameters

The following parameters are available in the `osg::cvmfs` class:

* [`manage_user`](#manage_user)
* [`user_name`](#user_name)
* [`user_uid`](#user_uid)
* [`user_home`](#user_home)
* [`user_shell`](#user_shell)
* [`user_system`](#user_system)
* [`user_comment`](#user_comment)
* [`user_managehome`](#user_managehome)
* [`manage_group`](#manage_group)
* [`group_name`](#group_name)
* [`group_gid`](#group_gid)
* [`group_system`](#group_system)
* [`manage_fuse_group`](#manage_fuse_group)
* [`fuse_group_name`](#fuse_group_name)
* [`fuse_group_gid`](#fuse_group_gid)
* [`fuse_group_system`](#fuse_group_system)
* [`package_ensure`](#package_ensure)
* [`repositories`](#repositories)
* [`strict_mount`](#strict_mount)
* [`cache_base`](#cache_base)
* [`quota_limit`](#quota_limit)
* [`http_proxies`](#http_proxies)
* [`cern_server_urls`](#cern_server_urls)
* [`glite_version`](#glite_version)
* [`cms_local_site`](#cms_local_site)

##### <a name="manage_user"></a>`manage_user`

Data type: `Boolean`

Boolean to set if CVMFS user is managed

Default value: ``true``

##### <a name="user_name"></a>`user_name`

Data type: `String`

CVMFS user name

Default value: `'cvmfs'`

##### <a name="user_uid"></a>`user_uid`

Data type: `Optional[Integer]`

CVMFS user UID

Default value: ``undef``

##### <a name="user_home"></a>`user_home`

Data type: `String`

CVMFS user home

Default value: `'/var/lib/cvmfs'`

##### <a name="user_shell"></a>`user_shell`

Data type: `String`

CVMFS user shell

Default value: `'/sbin/nologin'`

##### <a name="user_system"></a>`user_system`

Data type: `Boolean`

Sets if CVMFS user is a system account

Default value: ``true``

##### <a name="user_comment"></a>`user_comment`

Data type: `String`

CVMFS user comment

Default value: `'CernVM-FS service account'`

##### <a name="user_managehome"></a>`user_managehome`

Data type: `Boolean`

Sets if CVMFS user home is managed

Default value: ``false``

##### <a name="manage_group"></a>`manage_group`

Data type: `Boolean`

Boolean to set if CVMFS group is managed

Default value: ``true``

##### <a name="group_name"></a>`group_name`

Data type: `String`

CVMFS group name

Default value: `'cvmfs'`

##### <a name="group_gid"></a>`group_gid`

Data type: `Optional[Integer]`

CVMFS group GID

Default value: ``undef``

##### <a name="group_system"></a>`group_system`

Data type: `Boolean`

Sets if CVMFS group is a system account

Default value: ``true``

##### <a name="manage_fuse_group"></a>`manage_fuse_group`

Data type: `Boolean`

Manage FUSE group

Default value: ``true``

##### <a name="fuse_group_name"></a>`fuse_group_name`

Data type: `String`

FUSE group name

Default value: `'fuse'`

##### <a name="fuse_group_gid"></a>`fuse_group_gid`

Data type: `Optional[Integer]`

FUSE group GID

Default value: ``undef``

##### <a name="fuse_group_system"></a>`fuse_group_system`

Data type: `Boolean`

Sets if FUSE group is a system account

Default value: ``true``

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

Ensure property for CVMFS package

Default value: `'installed'`

##### <a name="repositories"></a>`repositories`

Data type: `Optional[Array]`

CVMFS repositories to enable, eg: `grid.cern.ch`

Default value: ``undef``

##### <a name="strict_mount"></a>`strict_mount`

Data type: `Boolean`

Enable CVMFS strict mount, only allow mounting repositories from `repositories` parameter

Default value: ``false``

##### <a name="cache_base"></a>`cache_base`

Data type: `String`

Base directory for CVMFS cache

Default value: `'/var/cache/cvmfs'`

##### <a name="quota_limit"></a>`quota_limit`

Data type: `Integer`

Quota limit for CVMFS cache

Default value: `20000`

##### <a name="http_proxies"></a>`http_proxies`

Data type: `Array`

Squid HTTP proxies for CVMFS

Default value: `["http://squid.${facts['networking']['domain']}:3128"]`

##### <a name="cern_server_urls"></a>`cern_server_urls`

Data type: `Array`

Value for `CVMFS_SERVER_URL`

Default value: `[]`

##### <a name="glite_version"></a>`glite_version`

Data type: `String`

glite version

Default value: `''`

##### <a name="cms_local_site"></a>`cms_local_site`

Data type: `Optional[String]`

Value for `CMS_LOCAL_SITE`

Default value: ``undef``

### <a name="osgfetchcrl"></a>`osg::fetchcrl`

Manage OSG fetchcrl

#### Parameters

The following parameters are available in the `osg::fetchcrl` class:

* [`ensure`](#ensure)
* [`crl_package_name`](#crl_package_name)
* [`crl_package_ensure`](#crl_package_ensure)
* [`crl_boot_service_name`](#crl_boot_service_name)
* [`crl_boot_service_ensure`](#crl_boot_service_ensure)
* [`crl_boot_service_enable`](#crl_boot_service_enable)
* [`crl_cron_service_name`](#crl_cron_service_name)
* [`crl_cron_service_ensure`](#crl_cron_service_ensure)
* [`crl_cron_service_enable`](#crl_cron_service_enable)
* [`use_syslog`](#use_syslog)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent', 'disabled']`

State of OSG fetchcrl
`disabled` will install but disable service

Default value: `'present'`

##### <a name="crl_package_name"></a>`crl_package_name`

Data type: `String`

fetch-crl package name

Default value: `'fetch-crl'`

##### <a name="crl_package_ensure"></a>`crl_package_ensure`

Data type: `String`

Ensure property for fetch-crl package

Default value: `'UNSET'`

##### <a name="crl_boot_service_name"></a>`crl_boot_service_name`

Data type: `String`

fetch-crl-boot package name

Default value: `'fetch-crl-boot'`

##### <a name="crl_boot_service_ensure"></a>`crl_boot_service_ensure`

Data type: `String`

fetch-crl-boot service ensure

Default value: `'stopped'`

##### <a name="crl_boot_service_enable"></a>`crl_boot_service_enable`

Data type: `Boolean`

fetch-crl-boot service enable

Default value: ``false``

##### <a name="crl_cron_service_name"></a>`crl_cron_service_name`

Data type: `String`

fetch-crl-cron service name

Default value: `'fetch-crl-cron'`

##### <a name="crl_cron_service_ensure"></a>`crl_cron_service_ensure`

Data type: `String`

fetch-crl-cron service ensure

Default value: `'UNSET'`

##### <a name="crl_cron_service_enable"></a>`crl_cron_service_enable`

Data type: `Variant[Boolean, Enum['UNSET']]`

fetch-crl-cron service enable

Default value: `'UNSET'`

##### <a name="use_syslog"></a>`use_syslog`

Data type: `Boolean`

Boolean to set if syslog should be used

Default value: ``true``

### <a name="osggridftp"></a>`osg::gridftp`

Manage OSG GridFTP.

#### Parameters

The following parameters are available in the `osg::gridftp` class:

* [`manage_hostcert`](#manage_hostcert)
* [`hostcert_source`](#hostcert_source)
* [`hostkey_source`](#hostkey_source)
* [`manage_firewall`](#manage_firewall)
* [`standalone`](#standalone)

##### <a name="manage_hostcert"></a>`manage_hostcert`

Data type: `Boolean`

Boolean to set if hostcert should be managed

Default value: ``true``

##### <a name="hostcert_source"></a>`hostcert_source`

Data type: `Optional[String]`

Source for hostcert

Default value: ``undef``

##### <a name="hostkey_source"></a>`hostkey_source`

Data type: `Optional[String]`

Source for hostkey

Default value: ``undef``

##### <a name="manage_firewall"></a>`manage_firewall`

Data type: `Boolean`

Boolean to set if the firewall resources should be managed

Default value: ``true``

##### <a name="standalone"></a>`standalone`

Data type: `Boolean`

Sets if the GridFTP server is standalone.
This parameter is considered private.
This parameter is intended for when installing GridFTP on a CE and is handled by `osg::ce` class

Default value: ``true``

### <a name="osglcmaps_voms"></a>`osg::lcmaps_voms`

Manage lcmaps VOMs

#### Parameters

The following parameters are available in the `osg::lcmaps_voms` class:

* [`ban_voms`](#ban_voms)
* [`ban_users`](#ban_users)
* [`vos`](#vos)
* [`users`](#users)

##### <a name="ban_voms"></a>`ban_voms`

Data type: `Array`

VOMs to ban

Default value: `[]`

##### <a name="ban_users"></a>`ban_users`

Data type: `Array`

Users to ban

Default value: `[]`

##### <a name="vos"></a>`vos`

Data type: `Hash[String, Variant[String, Array, Hash]]`

Define osg::lcmaps_voms::vo resources
Example: `{ 'vo' => '/DN' }`
Example: `{ 'vo' => { 'dn' => '/DN' } }`

Default value: `{}`

##### <a name="users"></a>`users`

Data type: `Hash[String, Variant[String, Array, Hash]]`

Define osg::lcmaps_voms::user resources
Example: `{ 'user' => '/DN' }`
Example: `{ 'user' => { 'dn' => '/DN' } }`

Default value: `{}`

### <a name="osgsquid"></a>`osg::squid`

Manage OSG squid

#### Parameters

The following parameters are available in the `osg::squid` class:

* [`customize_template`](#customize_template)
* [`net_local`](#net_local)
* [`monitor_addresses`](#monitor_addresses)
* [`allow_major_cvmfs`](#allow_major_cvmfs)
* [`max_filedescriptors`](#max_filedescriptors)
* [`manage_firewall`](#manage_firewall)
* [`squid_firewall_ensure`](#squid_firewall_ensure)
* [`monitoring_firewall_ensure`](#monitoring_firewall_ensure)
* [`private_interface`](#private_interface)
* [`public_interface`](#public_interface)

##### <a name="customize_template"></a>`customize_template`

Data type: `String`

Path to template used to customize squid

Default value: `'osg/squid/customize.sh.erb'`

##### <a name="net_local"></a>`net_local`

Data type: `Array`

Local networks

Default value: `['10.0.0.0/8', '172.16.0.0/12', '192.168.0.0/16']`

##### <a name="monitor_addresses"></a>`monitor_addresses`

Data type: `Array`

Monitor addresses

Default value: `['128.142.0.0/16', '188.184.128.0/17', '188.185.128.0/17']`

##### <a name="allow_major_cvmfs"></a>`allow_major_cvmfs`

Data type: `Boolean`

Enables and allows `MAJOR_CVMFS`

Default value: ``true``

##### <a name="max_filedescriptors"></a>`max_filedescriptors`

Data type: `Integer`

Sets `max_filedescriptors`

Default value: `0`

##### <a name="manage_firewall"></a>`manage_firewall`

Data type: `Boolean`

Manage firewall resources

Default value: ``true``

##### <a name="squid_firewall_ensure"></a>`squid_firewall_ensure`

Data type: `Enum['present', 'absent']`

Ensure property for squid firewall

Default value: `'present'`

##### <a name="monitoring_firewall_ensure"></a>`monitoring_firewall_ensure`

Data type: `Enum['present', 'absent']`

Ensure property for monitoring firewall

Default value: `'present'`

##### <a name="private_interface"></a>`private_interface`

Data type: `Optional[String]`

Private interface, used by firewall rules to allow squid access

Default value: ``undef``

##### <a name="public_interface"></a>`public_interface`

Data type: `Optional[String]`

Public interface, used by firewall rules to allow monitor addresses

Default value: ``undef``

### <a name="osgutils"></a>`osg::utils`

Manage OSG utils

#### Parameters

The following parameters are available in the `osg::utils` class:

* [`packages`](#packages)

##### <a name="packages"></a>`packages`

Data type: `Array`

Packages to install

Default value: `[
    'globus-proxy-utils',
    'osg-pki-tools',
  ]`

### <a name="osgwn"></a>`osg::wn`

Manage OSG worker node resources

## Defined types

### <a name="osglcmaps_vomsuser"></a>`osg::lcmaps_voms::user`

Manage lcmaps VOMs user

#### Parameters

The following parameters are available in the `osg::lcmaps_voms::user` defined type:

* [`dn`](#dn)
* [`user`](#user)
* [`order`](#order)

##### <a name="dn"></a>`dn`

Data type: `Variant[Array, String]`

DN of the user

##### <a name="user"></a>`user`

Data type: `String`

Name of the user

Default value: `$name`

##### <a name="order"></a>`order`

Data type: `Integer`

Order in the grid-mapfile

Default value: `50`

### <a name="osglcmaps_vomsvo"></a>`osg::lcmaps_voms::vo`

Manage lcmaps VOMs VO entry

#### Parameters

The following parameters are available in the `osg::lcmaps_voms::vo` defined type:

* [`dn`](#dn)
* [`user`](#user)
* [`order`](#order)

##### <a name="dn"></a>`dn`

Data type: `Variant[Array, String]`

DN of the VO

##### <a name="user"></a>`user`

Data type: `String`

User name

Default value: `$name`

##### <a name="order"></a>`order`

Data type: `Integer`

Order in voms-mapfile

Default value: `50`

## Resource types

### <a name="osg_gip_config"></a>`osg_gip_config`

This type writes values to `/etc/osg/config.d/30-gip.ini`

#### Properties

The following properties are available in the `osg_gip_config` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `value`

The value to assign.
A value of `true` is converted to the string `True`.
A value of `false` is converted to the string `False`.
All other values are converted to a string.

#### Parameters

The following parameters are available in the `osg_gip_config` type.

* [`name`](#name)
* [`provider`](#provider)

##### <a name="name"></a>`name`

namevar

The name must be in the format of `SECTION/SETTING`

    [GIP]
    batch = slurm

The above would have the name `GIP/batch`.

##### <a name="provider"></a>`provider`

The specific backend to use for this `osg_gip_config` resource. You will seldom need to specify this --- Puppet will
usually discover the appropriate provider for your platform.

### <a name="osg_local_site_settings"></a>`osg_local_site_settings`

This type writes values to `/etc/osg/config.d/99-local-site-settings.ini`.

#### Properties

The following properties are available in the `osg_local_site_settings` type.

##### `ensure`

Valid values: `present`, `absent`

The basic property that the resource should be in.

Default value: `present`

##### `value`

The value to assign.
A value of `true` is converted to the string `True`.
A value of `false` is converted to the string `False`.
All other values are converted to a string.

#### Parameters

The following parameters are available in the `osg_local_site_settings` type.

* [`name`](#name)
* [`provider`](#provider)

##### <a name="name"></a>`name`

namevar

The name must be in the format of `SECTION/SETTING`

    [Squid]
    location = squid.example.tld

The above would have the name `Squid/location`.

##### <a name="provider"></a>`provider`

The specific backend to use for this `osg_local_site_settings` resource. You will seldom need to specify this --- Puppet
will usually discover the appropriate provider for your platform.

